'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_ARB_make_current_read'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_ARB_make_current_read',error_checker=_errors._error_checker)
ERROR_INCOMPATIBLE_DEVICE_CONTEXTS_ARB=_C('ERROR_INCOMPATIBLE_DEVICE_CONTEXTS_ARB',0x2054)
ERROR_INVALID_PIXEL_TYPE_ARB=_C('ERROR_INVALID_PIXEL_TYPE_ARB',0x2043)
@_f
@_p.types(_cs.HDC,)
def wglGetCurrentReadDCARB():pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.HDC,_cs.HGLRC)
def wglMakeContextCurrentARB(hDrawDC,hReadDC,hglrc):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_gl_texture_cubemap_image'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_gl_texture_cubemap_image',error_checker=_errors._error_checker)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X_KHR',0x30B4)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_KHR',0x30B6)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_KHR',0x30B8)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X_KHR',0x30B3)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y_KHR',0x30B5)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z_KHR=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z_KHR',0x30B7)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_shading_language_include'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_shading_language_include',error_checker=_errors._error_checker)
GL_NAMED_STRING_LENGTH_ARB=_C('GL_NAMED_STRING_LENGTH_ARB',0x8DE9)
GL_NAMED_STRING_TYPE_ARB=_C('GL_NAMED_STRING_TYPE_ARB',0x8DEA)
GL_SHADER_INCLUDE_ARB=_C('GL_SHADER_INCLUDE_ARB',0x8DAE)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,ctypes.POINTER( ctypes.POINTER( _cs.GLchar )),arrays.GLintArray)
def glCompileShaderIncludeARB(shader,count,path,length):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLcharArray)
def glDeleteNamedStringARB(namelen,name):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLcharArray,_cs.GLsizei,arrays.GLintArray,arrays.GLcharArray)
def glGetNamedStringARB(namelen,name,bufSize,stringlen,string):pass
@_f
@_p.types(None,_cs.GLint,arrays.GLcharArray,_cs.GLenum,arrays.GLintArray)
def glGetNamedStringivARB(namelen,name,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLint,arrays.GLcharArray)
def glIsNamedStringARB(namelen,name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLcharArray,_cs.GLint,arrays.GLcharArray)
def glNamedStringARB(type,namelen,name,stringlen,string):pass



'''OpenGL extension SGIX.tag_sample_buffer

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.tag_sample_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	The extensions defines a special purpose fast multisample clear.
	This clear can be used with some restrictions as a significantly
	faster alternative to Clear(DEPTH_BUFFER_BIT).
	
	The extension is based on the RealityEngine architecture and will
	probably never be supported by any other architecture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/tag_sample_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.tag_sample_buffer import *
from OpenGL.raw.GL.SGIX.tag_sample_buffer import _EXTENSION_NAME

def glInitTagSampleBufferSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.compute_program5

This module customises the behaviour of the 
OpenGL.raw.GL.NV.compute_program5 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds on the ARB_compute_shader extension to provide new
	assembly compute program capability for OpenGL.  ARB_compute_shader adds
	the basic functionality, including the ability to dispatch compute work.
	This extension provides the ability to write a compute program in
	assembly, using the same basic syntax and capability set found in the
	NV_gpu_program4 and NV_gpu_program5 extensions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/compute_program5.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.compute_program5 import *
from OpenGL.raw.GL.NV.compute_program5 import _EXTENSION_NAME

def glInitComputeProgram5NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Selection-buffer handling code

This code is resonsible for turning gluint *
arrays into structured representations for use
by Python-level code.
"""
from OpenGL._bytes import integer_types

def uintToLong( value ):
    if value < 0:
        # array type without a uint, so represented as an int 
        value = (value & 0x7fffffff) + 0x80000000
    return value

class GLSelectRecord( object ):
    """Minimalist object for storing an OpenGL selection-buffer record
    
    Provides near and far as *float* values by dividing by 
    self.DISTANCE_DIVISOR (2**32-1)
    From the spec:
        Depth values (which are in the range [0,1]) are multiplied by 
        2^32 - 1, before being placed in the hit record.
    
    Names are unmodified, so normally are slices of the array passed in 
    to GLSelectRecord.fromArray( array )
    """
    DISTANCE_DIVISOR = float((2**32)-1)
    __slots__ = ('near','far','names')
    def fromArray( cls, array, total ):
        """Produce list with all records from the array"""
        result = []
        index = 0
        arrayLength = len(array)
        for item in range( total ):
            if index + 2 >= arrayLength:
                break
            count = array[index]
            near = array[index+1]
            far = array[index+2]
            names = [ uintToLong(v) for v in array[index+3:index+3+count]]
            result.append(  cls( near, far, names ) )
            index += 3+count
        return result
    fromArray = classmethod( fromArray )
    
    def __init__( self, near, far, names ):
        """Initialise/store the values"""
        self.near = self.convertDistance( near )
        self.far = self.convertDistance( far )
        self.names = names 
    def convertDistance( self, value ):
        """Convert a distance value from array uint to 0.0-1.0 range float"""
        return uintToLong( value ) / self.DISTANCE_DIVISOR
    def __getitem__( self, key ):
        """Allow for treating the record as a three-tuple"""
        if isinstance( key, integer_types):
            return (self.near,self.far,self.names)[key]
        elif key in self.__slots__:
            try:
                return getattr( self, key )
            except AttributeError as err:
                raise KeyError( """Don't have an index/key %r for %s instant"""%(
                    key, self.__class__,
                ))



'''OpenGL extension EXT.debug_label

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.debug_label to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/debug_label.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.debug_label import *
from OpenGL.raw.GLES2.EXT.debug_label import _EXTENSION_NAME

def glInitDebugLabelEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGetObjectLabelEXT.label size not checked against bufSize
glGetObjectLabelEXT=wrapper.wrapper(glGetObjectLabelEXT).setInputArraySize(
    'label', None
).setInputArraySize(
    'length', 1
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.bindless_multi_draw_indirect

This module customises the behaviour of the 
OpenGL.raw.GL.NV.bindless_multi_draw_indirect to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension combines NV_vertex_buffer_unified_memory and 
	ARB_multi_draw_indirect to allow the processing of multiple drawing
	commands, whose vertex and index data can be sourced from arbitrary 
	buffer locations, by a single function call.
	
	The NV_vertex_buffer_unified_memory extension provided a mechanism to 
	specify vertex attrib and element array locations using GPU addresses.
	Prior to this extension, these addresses had to be set through explicit
	function calls. Now the ability to set the pointer addresses indirectly
	by extending the GL_ARB_draw_indirect mechanism has been added.
	
	Combined with other "bindless" extensions, such as NV_bindless_texture and
	NV_shader_buffer_load, it is now possible for the GPU to create draw
	commands that source all resource inputs, which are common to change 
	frequently between draw calls from the GPU: vertex and index buffers, 
	samplers, images and other shader input data stored in buffers.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/bindless_multi_draw_indirect.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.bindless_multi_draw_indirect import *
from OpenGL.raw.GL.NV.bindless_multi_draw_indirect import _EXTENSION_NAME

def glInitBindlessMultiDrawIndirectNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_VERSION_EGL_1_5'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_VERSION_EGL_1_5',error_checker=_errors._error_checker)
EGL_CL_EVENT_HANDLE=_C('EGL_CL_EVENT_HANDLE',0x309C)
EGL_CONDITION_SATISFIED=_C('EGL_CONDITION_SATISFIED',0x30F6)
EGL_CONTEXT_MAJOR_VERSION=_C('EGL_CONTEXT_MAJOR_VERSION',0x3098)
EGL_CONTEXT_MINOR_VERSION=_C('EGL_CONTEXT_MINOR_VERSION',0x30FB)
EGL_CONTEXT_OPENGL_COMPATIBILITY_PROFILE_BIT=_C('EGL_CONTEXT_OPENGL_COMPATIBILITY_PROFILE_BIT',0x00000002)
EGL_CONTEXT_OPENGL_CORE_PROFILE_BIT=_C('EGL_CONTEXT_OPENGL_CORE_PROFILE_BIT',0x00000001)
EGL_CONTEXT_OPENGL_DEBUG=_C('EGL_CONTEXT_OPENGL_DEBUG',0x31B0)
EGL_CONTEXT_OPENGL_FORWARD_COMPATIBLE=_C('EGL_CONTEXT_OPENGL_FORWARD_COMPATIBLE',0x31B1)
EGL_CONTEXT_OPENGL_PROFILE_MASK=_C('EGL_CONTEXT_OPENGL_PROFILE_MASK',0x30FD)
EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY=_C('EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY',0x31BD)
EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY=_C('EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY',0x31BD)
EGL_CONTEXT_OPENGL_ROBUST_ACCESS=_C('EGL_CONTEXT_OPENGL_ROBUST_ACCESS',0x31B2)
EGL_CONTEXT_OPENGL_ROBUST_ACCESS=_C('EGL_CONTEXT_OPENGL_ROBUST_ACCESS',0x31B2)
EGL_FOREVER=_C('EGL_FOREVER',0xFFFFFFFFFFFFFFFF)
EGL_GL_COLORSPACE=_C('EGL_GL_COLORSPACE',0x309D)
EGL_GL_COLORSPACE_LINEAR=_C('EGL_GL_COLORSPACE_LINEAR',0x308A)
EGL_GL_COLORSPACE_SRGB=_C('EGL_GL_COLORSPACE_SRGB',0x3089)
EGL_GL_RENDERBUFFER=_C('EGL_GL_RENDERBUFFER',0x30B9)
EGL_GL_TEXTURE_2D=_C('EGL_GL_TEXTURE_2D',0x30B1)
EGL_GL_TEXTURE_3D=_C('EGL_GL_TEXTURE_3D',0x30B2)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_X',0x30B4)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Y',0x30B6)
EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z=_C('EGL_GL_TEXTURE_CUBE_MAP_NEGATIVE_Z',0x30B8)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_X',0x30B3)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Y',0x30B5)
EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z=_C('EGL_GL_TEXTURE_CUBE_MAP_POSITIVE_Z',0x30B7)
EGL_GL_TEXTURE_LEVEL=_C('EGL_GL_TEXTURE_LEVEL',0x30BC)
EGL_GL_TEXTURE_ZOFFSET=_C('EGL_GL_TEXTURE_ZOFFSET',0x30BD)
EGL_IMAGE_PRESERVED=_C('EGL_IMAGE_PRESERVED',0x30D2)
EGL_LOSE_CONTEXT_ON_RESET=_C('EGL_LOSE_CONTEXT_ON_RESET',0x31BF)
# EGL_NO_IMAGE=_C('EGL_NO_IMAGE',((EGLImage)0))
EGL_NO_RESET_NOTIFICATION=_C('EGL_NO_RESET_NOTIFICATION',0x31BE)
# EGL_NO_SYNC=_C('EGL_NO_SYNC',((EGLSync)0))
EGL_OPENGL_ES3_BIT=_C('EGL_OPENGL_ES3_BIT',0x00000040)
EGL_SIGNALED=_C('EGL_SIGNALED',0x30F2)
EGL_SYNC_CL_EVENT=_C('EGL_SYNC_CL_EVENT',0x30FE)
EGL_SYNC_CL_EVENT_COMPLETE=_C('EGL_SYNC_CL_EVENT_COMPLETE',0x30FF)
EGL_SYNC_CONDITION=_C('EGL_SYNC_CONDITION',0x30F8)
EGL_SYNC_FENCE=_C('EGL_SYNC_FENCE',0x30F9)
EGL_SYNC_FLUSH_COMMANDS_BIT=_C('EGL_SYNC_FLUSH_COMMANDS_BIT',0x0001)
EGL_SYNC_PRIOR_COMMANDS_COMPLETE=_C('EGL_SYNC_PRIOR_COMMANDS_COMPLETE',0x30F0)
EGL_SYNC_STATUS=_C('EGL_SYNC_STATUS',0x30F1)
EGL_SYNC_TYPE=_C('EGL_SYNC_TYPE',0x30F7)
EGL_TIMEOUT_EXPIRED=_C('EGL_TIMEOUT_EXPIRED',0x30F5)
EGL_UNSIGNALED=_C('EGL_UNSIGNALED',0x30F3)
@_f
@_p.types(_cs.EGLint,_cs.EGLDisplay,_cs.EGLSync,_cs.EGLint,_cs.EGLTime)
def eglClientWaitSync(dpy,sync,flags,timeout):pass
@_f
@_p.types(_cs.EGLImage,_cs.EGLDisplay,_cs.EGLContext,_cs.EGLenum,_cs.EGLClientBuffer,arrays.EGLAttribArray)
def eglCreateImage(dpy,ctx,target,buffer,attrib_list):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,ctypes.c_void_p,arrays.EGLAttribArray)
def eglCreatePlatformPixmapSurface(dpy,config,native_pixmap,attrib_list):pass
@_f
@_p.types(_cs.EGLSurface,_cs.EGLDisplay,_cs.EGLConfig,ctypes.c_void_p,arrays.EGLAttribArray)
def eglCreatePlatformWindowSurface(dpy,config,native_window,attrib_list):pass
@_f
@_p.types(_cs.EGLSync,_cs.EGLDisplay,_cs.EGLenum,arrays.EGLAttribArray)
def eglCreateSync(dpy,type,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLImage)
def eglDestroyImage(dpy,image):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSync)
def eglDestroySync(dpy,sync):pass
@_f
@_p.types(_cs.EGLDisplay,_cs.EGLenum,ctypes.c_void_p,arrays.EGLAttribArray)
def eglGetPlatformDisplay(platform,native_display,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSync,_cs.EGLint,arrays.EGLAttribArray)
def eglGetSyncAttrib(dpy,sync,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSync,_cs.EGLint)
def eglWaitSync(dpy,sync,flags):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_NV_video_output'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_NV_video_output',error_checker=_errors._error_checker)
GLX_VIDEO_OUT_ALPHA_NV=_C('GLX_VIDEO_OUT_ALPHA_NV',0x20C4)
GLX_VIDEO_OUT_COLOR_AND_ALPHA_NV=_C('GLX_VIDEO_OUT_COLOR_AND_ALPHA_NV',0x20C6)
GLX_VIDEO_OUT_COLOR_AND_DEPTH_NV=_C('GLX_VIDEO_OUT_COLOR_AND_DEPTH_NV',0x20C7)
GLX_VIDEO_OUT_COLOR_NV=_C('GLX_VIDEO_OUT_COLOR_NV',0x20C3)
GLX_VIDEO_OUT_DEPTH_NV=_C('GLX_VIDEO_OUT_DEPTH_NV',0x20C5)
GLX_VIDEO_OUT_FIELD_1_NV=_C('GLX_VIDEO_OUT_FIELD_1_NV',0x20C9)
GLX_VIDEO_OUT_FIELD_2_NV=_C('GLX_VIDEO_OUT_FIELD_2_NV',0x20CA)
GLX_VIDEO_OUT_FRAME_NV=_C('GLX_VIDEO_OUT_FRAME_NV',0x20C8)
GLX_VIDEO_OUT_STACKED_FIELDS_1_2_NV=_C('GLX_VIDEO_OUT_STACKED_FIELDS_1_2_NV',0x20CB)
GLX_VIDEO_OUT_STACKED_FIELDS_2_1_NV=_C('GLX_VIDEO_OUT_STACKED_FIELDS_2_1_NV',0x20CC)
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXVideoDeviceNV,_cs.GLXPbuffer,_cs.c_int)
def glXBindVideoImageNV(dpy,VideoDevice,pbuf,iVideoBuffer):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.c_int,ctypes.POINTER(_cs.GLXVideoDeviceNV))
def glXGetVideoDeviceNV(dpy,screen,numVideoDevices,pVideoDevice):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.GLXVideoDeviceNV,ctypes.POINTER(_cs.c_ulong),ctypes.POINTER(_cs.c_ulong))
def glXGetVideoInfoNV(dpy,screen,VideoDevice,pulCounterOutputPbuffer,pulCounterOutputVideo):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_int,_cs.GLXVideoDeviceNV)
def glXReleaseVideoDeviceNV(dpy,screen,VideoDevice):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXPbuffer)
def glXReleaseVideoImageNV(dpy,pbuf):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXPbuffer,_cs.c_int,ctypes.POINTER(_cs.c_ulong),_cs.GLboolean)
def glXSendPbufferToVideoNV(dpy,pbuf,iBufferType,pulCounterPbuffer,bBlock):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_ANGLE_instanced_arrays'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_ANGLE_instanced_arrays',error_checker=_errors._error_checker)
GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE=_C('GL_VERTEX_ATTRIB_ARRAY_DIVISOR_ANGLE',0x88FE)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glDrawArraysInstancedANGLE(mode,first,count,primcount):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p,_cs.GLsizei)
def glDrawElementsInstancedANGLE(mode,count,type,indices,primcount):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glVertexAttribDivisorANGLE(index,divisor):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_packed_pixels'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_packed_pixels',error_checker=_errors._error_checker)
GL_UNSIGNED_BYTE_3_3_2_EXT=_C('GL_UNSIGNED_BYTE_3_3_2_EXT',0x8032)
GL_UNSIGNED_INT_10_10_10_2_EXT=_C('GL_UNSIGNED_INT_10_10_10_2_EXT',0x8036)
GL_UNSIGNED_INT_8_8_8_8_EXT=_C('GL_UNSIGNED_INT_8_8_8_8_EXT',0x8035)
GL_UNSIGNED_SHORT_4_4_4_4_EXT=_C('GL_UNSIGNED_SHORT_4_4_4_4_EXT',0x8033)
GL_UNSIGNED_SHORT_5_5_5_1_EXT=_C('GL_UNSIGNED_SHORT_5_5_5_1_EXT',0x8034)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_image_base'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_image_base',error_checker=_errors._error_checker)
EGL_IMAGE_PRESERVED_KHR=_C('EGL_IMAGE_PRESERVED_KHR',0x30D2)
# EGL_NO_IMAGE_KHR=_C('EGL_NO_IMAGE_KHR',((EGLImageKHR)0))
@_f
@_p.types(_cs.EGLImageKHR,_cs.EGLDisplay,_cs.EGLContext,_cs.EGLenum,_cs.EGLClientBuffer,arrays.GLintArray)
def eglCreateImageKHR(dpy,ctx,target,buffer,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLImageKHR)
def eglDestroyImageKHR(dpy,image):pass



'''OpenGL extension NV.texgen_reflection

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texgen_reflection to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides two new texture coordinate generation modes
	that are useful texture-based lighting and environment mapping.
	The reflection map mode generates texture coordinates (s,t,r)
	matching the vertex's eye-space reflection vector.  The reflection
	map mode is useful for environment mapping without the singularity
	inherent in sphere mapping.  The normal map mode generates texture
	coordinates (s,t,r) matching the vertex's transformed eye-space
	normal.  The normal map mode is useful for sophisticated cube map
	texturing-based diffuse lighting models.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texgen_reflection.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.texgen_reflection import *
from OpenGL.raw.GL.NV.texgen_reflection import _EXTENSION_NAME

def glInitTexgenReflectionNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_NV_gpu_affinity'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_NV_gpu_affinity',error_checker=_errors._error_checker)
ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV=_C('ERROR_INCOMPATIBLE_AFFINITY_MASKS_NV',0x20D0)
ERROR_MISSING_AFFINITY_MASK_NV=_C('ERROR_MISSING_AFFINITY_MASK_NV',0x20D1)
@_f
@_p.types(_cs.HDC,ctypes.POINTER(_cs.HGPUNV))
def wglCreateAffinityDCNV(phGpuList):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC)
def wglDeleteDCNV(hdc):pass
@_f
@_p.types(_cs.BOOL,_cs.HGPUNV,_cs.UINT,_cs.PGPU_DEVICE)
def wglEnumGpuDevicesNV(hGpu,iDeviceIndex,lpGpuDevice):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.UINT,ctypes.POINTER(_cs.HGPUNV))
def wglEnumGpusFromAffinityDCNV(hAffinityDC,iGpuIndex,hGpu):pass
@_f
@_p.types(_cs.BOOL,_cs.UINT,ctypes.POINTER(_cs.HGPUNV))
def wglEnumGpusNV(iGpuIndex,phGpu):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_NV_vertex_array_range'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_NV_vertex_array_range',error_checker=_errors._error_checker)

@_f
@_p.types(ctypes.c_void_p,_cs.GLsizei,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def wglAllocateMemoryNV(size,readfreq,writefreq,priority):pass
@_f
@_p.types(None,ctypes.c_void_p)
def wglFreeMemoryNV(pointer):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_VERSION_GLX_1_3'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_VERSION_GLX_1_3',error_checker=_errors._error_checker)
GLX_ACCUM_BUFFER_BIT=_C('GLX_ACCUM_BUFFER_BIT',0x00000080)
GLX_AUX_BUFFERS_BIT=_C('GLX_AUX_BUFFERS_BIT',0x00000010)
GLX_BACK_LEFT_BUFFER_BIT=_C('GLX_BACK_LEFT_BUFFER_BIT',0x00000004)
GLX_BACK_RIGHT_BUFFER_BIT=_C('GLX_BACK_RIGHT_BUFFER_BIT',0x00000008)
GLX_COLOR_INDEX_BIT=_C('GLX_COLOR_INDEX_BIT',0x00000002)
GLX_COLOR_INDEX_TYPE=_C('GLX_COLOR_INDEX_TYPE',0x8015)
GLX_CONFIG_CAVEAT=_C('GLX_CONFIG_CAVEAT',0x20)
GLX_DAMAGED=_C('GLX_DAMAGED',0x8020)
GLX_DEPTH_BUFFER_BIT=_C('GLX_DEPTH_BUFFER_BIT',0x00000020)
GLX_DIRECT_COLOR=_C('GLX_DIRECT_COLOR',0x8003)
GLX_DONT_CARE=_C('GLX_DONT_CARE',0xFFFFFFFF)
GLX_DRAWABLE_TYPE=_C('GLX_DRAWABLE_TYPE',0x8010)
GLX_EVENT_MASK=_C('GLX_EVENT_MASK',0x801F)
GLX_FBCONFIG_ID=_C('GLX_FBCONFIG_ID',0x8013)
GLX_FRONT_LEFT_BUFFER_BIT=_C('GLX_FRONT_LEFT_BUFFER_BIT',0x00000001)
GLX_FRONT_RIGHT_BUFFER_BIT=_C('GLX_FRONT_RIGHT_BUFFER_BIT',0x00000002)
GLX_GRAY_SCALE=_C('GLX_GRAY_SCALE',0x8006)
GLX_HEIGHT=_C('GLX_HEIGHT',0x801E)
GLX_LARGEST_PBUFFER=_C('GLX_LARGEST_PBUFFER',0x801C)
GLX_MAX_PBUFFER_HEIGHT=_C('GLX_MAX_PBUFFER_HEIGHT',0x8017)
GLX_MAX_PBUFFER_PIXELS=_C('GLX_MAX_PBUFFER_PIXELS',0x8018)
GLX_MAX_PBUFFER_WIDTH=_C('GLX_MAX_PBUFFER_WIDTH',0x8016)
GLX_NONE=_C('GLX_NONE',0x8000)
GLX_NON_CONFORMANT_CONFIG=_C('GLX_NON_CONFORMANT_CONFIG',0x800D)
GLX_PBUFFER=_C('GLX_PBUFFER',0x8023)
GLX_PBUFFER_BIT=_C('GLX_PBUFFER_BIT',0x00000004)
GLX_PBUFFER_CLOBBER_MASK=_C('GLX_PBUFFER_CLOBBER_MASK',0x08000000)
GLX_PBUFFER_HEIGHT=_C('GLX_PBUFFER_HEIGHT',0x8040)
GLX_PBUFFER_WIDTH=_C('GLX_PBUFFER_WIDTH',0x8041)
GLX_PIXMAP_BIT=_C('GLX_PIXMAP_BIT',0x00000002)
GLX_PRESERVED_CONTENTS=_C('GLX_PRESERVED_CONTENTS',0x801B)
GLX_PSEUDO_COLOR=_C('GLX_PSEUDO_COLOR',0x8004)
GLX_RENDER_TYPE=_C('GLX_RENDER_TYPE',0x8011)
GLX_RGBA_BIT=_C('GLX_RGBA_BIT',0x00000001)
GLX_RGBA_TYPE=_C('GLX_RGBA_TYPE',0x8014)
GLX_SAVED=_C('GLX_SAVED',0x8021)
GLX_SCREEN=_C('GLX_SCREEN',0x800C)
GLX_SLOW_CONFIG=_C('GLX_SLOW_CONFIG',0x8001)
GLX_STATIC_COLOR=_C('GLX_STATIC_COLOR',0x8005)
GLX_STATIC_GRAY=_C('GLX_STATIC_GRAY',0x8007)
GLX_STENCIL_BUFFER_BIT=_C('GLX_STENCIL_BUFFER_BIT',0x00000040)
GLX_TRANSPARENT_ALPHA_VALUE=_C('GLX_TRANSPARENT_ALPHA_VALUE',0x28)
GLX_TRANSPARENT_BLUE_VALUE=_C('GLX_TRANSPARENT_BLUE_VALUE',0x27)
GLX_TRANSPARENT_GREEN_VALUE=_C('GLX_TRANSPARENT_GREEN_VALUE',0x26)
GLX_TRANSPARENT_INDEX=_C('GLX_TRANSPARENT_INDEX',0x8009)
GLX_TRANSPARENT_INDEX_VALUE=_C('GLX_TRANSPARENT_INDEX_VALUE',0x24)
GLX_TRANSPARENT_RED_VALUE=_C('GLX_TRANSPARENT_RED_VALUE',0x25)
GLX_TRANSPARENT_RGB=_C('GLX_TRANSPARENT_RGB',0x8008)
GLX_TRANSPARENT_TYPE=_C('GLX_TRANSPARENT_TYPE',0x23)
GLX_TRUE_COLOR=_C('GLX_TRUE_COLOR',0x8002)
GLX_VISUAL_ID=_C('GLX_VISUAL_ID',0x800B)
GLX_WIDTH=_C('GLX_WIDTH',0x801D)
GLX_WINDOW=_C('GLX_WINDOW',0x8022)
GLX_WINDOW_BIT=_C('GLX_WINDOW_BIT',0x00000001)
GLX_X_RENDERABLE=_C('GLX_X_RENDERABLE',0x8012)
GLX_X_VISUAL_TYPE=_C('GLX_X_VISUAL_TYPE',0x22)
@_f
@_p.types(ctypes.POINTER(_cs.GLXFBConfig),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def glXChooseFBConfig(dpy,screen,attrib_list,nelements):pass
@_f
@_p.types(_cs.GLXContext,ctypes.POINTER(_cs.Display),_cs.GLXFBConfig,_cs.c_int,_cs.GLXContext,_cs.Bool)
def glXCreateNewContext(dpy,config,render_type,share_list,direct):pass
@_f
@_p.types(_cs.GLXPbuffer,ctypes.POINTER(_cs.Display),_cs.GLXFBConfig,ctypes.POINTER(_cs.c_int))
def glXCreatePbuffer(dpy,config,attrib_list):pass
@_f
@_p.types(_cs.GLXPixmap,ctypes.POINTER(_cs.Display),_cs.GLXFBConfig,_cs.Pixmap,ctypes.POINTER(_cs.c_int))
def glXCreatePixmap(dpy,config,pixmap,attrib_list):pass
@_f
@_p.types(_cs.GLXWindow,ctypes.POINTER(_cs.Display),_cs.GLXFBConfig,_cs.Window,ctypes.POINTER(_cs.c_int))
def glXCreateWindow(dpy,config,win,attrib_list):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXPbuffer)
def glXDestroyPbuffer(dpy,pbuf):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXPixmap)
def glXDestroyPixmap(dpy,pixmap):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXWindow)
def glXDestroyWindow(dpy,win):pass
@_f
@_p.types(_cs.GLXDrawable,)
def glXGetCurrentReadDrawable():pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXFBConfig,_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXGetFBConfigAttrib(dpy,config,attribute,value):pass
@_f
@_p.types(ctypes.POINTER(_cs.GLXFBConfig),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXGetFBConfigs(dpy,screen,nelements):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,ctypes.POINTER(_cs.c_ulong))
def glXGetSelectedEvent(dpy,draw,event_mask):pass
@_f
@_p.types(ctypes.POINTER(_cs.XVisualInfo),ctypes.POINTER(_cs.Display),_cs.GLXFBConfig)
def glXGetVisualFromFBConfig(dpy,config):pass
@_f
@_p.types(_cs.Bool,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.GLXDrawable,_cs.GLXContext)
def glXMakeContextCurrent(dpy,draw,read,ctx):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXContext,_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXQueryContext(dpy,ctx,attribute,value):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.c_int,ctypes.POINTER(_cs.c_uint))
def glXQueryDrawable(dpy,draw,attribute,value):pass
@_f
@_p.types(None,ctypes.POINTER(_cs.Display),_cs.GLXDrawable,_cs.c_ulong)
def glXSelectEvent(dpy,draw,event_mask):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_IMG_user_clip_plane'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_IMG_user_clip_plane',error_checker=_errors._error_checker)
GL_CLIP_PLANE0_IMG=_C('GL_CLIP_PLANE0_IMG',0x3000)
GL_CLIP_PLANE1_IMG=_C('GL_CLIP_PLANE1_IMG',0x3001)
GL_CLIP_PLANE2_IMG=_C('GL_CLIP_PLANE2_IMG',0x3002)
GL_CLIP_PLANE3_IMG=_C('GL_CLIP_PLANE3_IMG',0x3003)
GL_CLIP_PLANE4_IMG=_C('GL_CLIP_PLANE4_IMG',0x3004)
GL_CLIP_PLANE5_IMG=_C('GL_CLIP_PLANE5_IMG',0x3005)
GL_MAX_CLIP_PLANES_IMG=_C('GL_MAX_CLIP_PLANES_IMG',0x0D32)
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glClipPlanefIMG(p,eqn):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glClipPlanexIMG(p,eqn):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_copy_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_copy_texture',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLint)
def glCopyTexImage1DEXT(target,level,internalformat,x,y,width,border):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLint)
def glCopyTexImage2DEXT(target,level,internalformat,x,y,width,height,border):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyTexSubImage1DEXT(target,level,xoffset,x,y,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyTexSubImage2DEXT(target,level,xoffset,yoffset,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyTexSubImage3DEXT(target,level,xoffset,yoffset,zoffset,x,y,width,height):pass



'''OpenGL extension IBM.cull_vertex

This module customises the behaviour of the 
OpenGL.raw.GL.IBM.cull_vertex to provide a more 
Python-friendly API

Overview (from the spec)
	
	IBM_cull_vertex provides a subset of the vertex culling functionality
	found in EXT_cull_vertex without providing a guarantee that faces will
	be culled because of it.  EXT_cull_vertex is a technically superior
	solution, but the vertex culling aspect of IBM_cull_vertex provides
	generally useful function cheaply (without imposing the mandated
	culling found in EXT_cull_vertex).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IBM/cull_vertex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.IBM.cull_vertex import *
from OpenGL.raw.GL.IBM.cull_vertex import _EXTENSION_NAME

def glInitCullVertexIBM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension MESA.release_buffers

This module customises the behaviour of the 
OpenGL.raw.GLX.MESA.release_buffers to provide a more 
Python-friendly API

Overview (from the spec)
	
	Mesa's implementation of GLX is entirely implemented on the client side.
	Therefore, Mesa cannot immediately detect when an X window or pixmap is
	destroyed in order to free any ancilliary data associated with the window
	or pixmap.
	
	The glxMesaReleaseBuffers() function can be used to explicitly indicate
	when the back color buffer, depth buffer, stencil buffer, and/or accum-
	ulation buffer associated with a drawable can be freed.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/release_buffers.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.MESA.release_buffers import *
from OpenGL.raw.GLX.MESA.release_buffers import _EXTENSION_NAME

def glInitReleaseBuffersMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.point_parameters

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.point_parameters to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/point_parameters.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.point_parameters import *
from OpenGL.raw.GL.SGIS.point_parameters import _EXTENSION_NAME

def glInitPointParametersSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glPointParameterfvSGIS.params size not checked against 'pname'
glPointParameterfvSGIS=wrapper.wrapper(glPointParameterfvSGIS).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension SGIX.interlace

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.interlace to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a way to interlace rows of pixels when
	rasterizing pixel rectangles, and loading texture images.  In this
	context, interlacing means skiping over rows of pixels or texels
	in the destination.  This is useful for dealing with video data
	since a single frame of video is typically composed from two images
	or fields: one image specifying the data for even rows of the frame
	and the other image specifying the data for odd rows of the frame.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/interlace.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.interlace import *
from OpenGL.raw.GL.SGIX.interlace import _EXTENSION_NAME

def glInitInterlaceSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.gpu_affinity

This module customises the behaviour of the 
OpenGL.raw.WGL.NV.gpu_affinity to provide a more 
Python-friendly API

Overview (from the spec)
	
	On systems with more than one GPU it is desirable to be able to
	select which GPU(s) in the system become the target for OpenGL
	rendering commands. This extension introduces the concept of a GPU
	affinity mask. OpenGL rendering commands are directed to the
	GPU(s) specified by the affinity mask. GPU affinity is immutable.
	Once set, it cannot be changed.
	
	This extension also introduces the concept called affinity-DC. An
	affinity-DC is a device context with a GPU affinity mask embedded
	in it. This restricts the device context to only allow OpenGL
	commands to be sent to the GPU(s) in the affinity mask.
	
	Handles for the GPUs present in a system are enumerated with the
	command wglEnumGpusNV. An affinity-DC is created by calling
	wglCreateAffinityDCNV. This function takes a list of GPU handles,
	which make up the affinity mask. An affinity-DC can also
	indirectly be created by obtaining a DC from a pBuffer handle, by
	calling wglGetPbufferDC, which in turn was created from an
	affinity-DC by calling wglCreatePbuffer.
	
	A context created from an affinity DC will inherit the GPU
	affinity mask from the DC. Once inherited, it cannot be changed.
	Such a context is called an affinity-context. This restricts the
	affinity-context to only allow OpenGL commands to be sent to those
	GPU(s) in its affinity mask. Once created, this context can be
	used in two ways:
	
	  1. Make the affinity-context current to an affinity-DC. This
	     will only succeed if the context's affinity mask is the same
	     as the affinity mask in the DC. There is no window
	     associated with an affinity DC, therefore this is a way to
	     achieve off-screen rendering to an OpenGL context. This can
	     either be rendering to a pBuffer, or an application created
	     framebuffer object. In the former case, the affinity-mask of
	     the pBuffer DC, which is obtained from a pBuffer handle,
	     will be the same affinity-mask as the DC used to created the
	     pBuffer handle.  In the latter case, the default framebuffer
	     object will be incomplete because there is no window-system
	     created framebuffer. Therefore, the application will have to
	     create and bind a framebuffer object as the target for
	     rendering.
	  2. Make the affinity-context current to a DC obtained from a
	     window. Rendering only happens to the sub rectangles(s) of
	     the window that overlap the parts of the desktop that are
	     displayed by the GPU(s) in the affinity mask of the context.
	
	Sharing OpenGL objects between affinity-contexts, by calling
	wglShareLists, will only succeed if the contexts have identical
	affinity masks.
	
	It is not possible to make a regular context (one without an
	affinity mask) current to an affinity-DC. This would mean a way
	for a context to inherit affinity information, which makes the
	context affinity mutable, which is counter to the premise of this
	extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/gpu_affinity.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.NV.gpu_affinity import *
from OpenGL.raw.WGL.NV.gpu_affinity import _EXTENSION_NAME

def glInitGpuAffinityNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_shader_buffer_store'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_shader_buffer_store',error_checker=_errors._error_checker)
GL_READ_WRITE=_C('GL_READ_WRITE',0x88BA)
GL_SHADER_GLOBAL_ACCESS_BARRIER_BIT_NV=_C('GL_SHADER_GLOBAL_ACCESS_BARRIER_BIT_NV',0x00000010)
GL_WRITE_ONLY=_C('GL_WRITE_ONLY',0x88B9)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SUN_global_alpha'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SUN_global_alpha',error_checker=_errors._error_checker)
GL_GLOBAL_ALPHA_FACTOR_SUN=_C('GL_GLOBAL_ALPHA_FACTOR_SUN',0x81DA)
GL_GLOBAL_ALPHA_SUN=_C('GL_GLOBAL_ALPHA_SUN',0x81D9)
@_f
@_p.types(None,_cs.GLbyte)
def glGlobalAlphaFactorbSUN(factor):pass
@_f
@_p.types(None,_cs.GLdouble)
def glGlobalAlphaFactordSUN(factor):pass
@_f
@_p.types(None,_cs.GLfloat)
def glGlobalAlphaFactorfSUN(factor):pass
@_f
@_p.types(None,_cs.GLint)
def glGlobalAlphaFactoriSUN(factor):pass
@_f
@_p.types(None,_cs.GLshort)
def glGlobalAlphaFactorsSUN(factor):pass
@_f
@_p.types(None,_cs.GLubyte)
def glGlobalAlphaFactorubSUN(factor):pass
@_f
@_p.types(None,_cs.GLuint)
def glGlobalAlphaFactoruiSUN(factor):pass
@_f
@_p.types(None,_cs.GLushort)
def glGlobalAlphaFactorusSUN(factor):pass



'''OpenGL extension SGIS.fog_function

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.fog_function to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows to define application-specific fog blend-factor
	function.  Function is defined by the set of the "control" points and
	should be monotonic. Each control point represented as a pair of the
	eye-space distance value and corresponding value of the fog blending 
	factor. The minimum number of control points is one. The maximum 
	number is implementation dependent.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/fog_function.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.fog_function import *
from OpenGL.raw.GL.SGIS.fog_function import _EXTENSION_NAME

def glInitFogFunctionSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glFogFuncSGIS.points size not checked against n*2
glFogFuncSGIS=wrapper.wrapper(glFogFuncSGIS).setInputArraySize(
    'points', None
)
glGetFogFuncSGIS=wrapper.wrapper(glGetFogFuncSGIS).setOutput(
    'points',size=_glgets._glget_size_mapping,pnameArg='',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_EXT_visual_rating'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_EXT_visual_rating',error_checker=_errors._error_checker)
GLX_NONE_EXT=_C('GLX_NONE_EXT',0x8000)
GLX_NON_CONFORMANT_VISUAL_EXT=_C('GLX_NON_CONFORMANT_VISUAL_EXT',0x800D)
GLX_SLOW_VISUAL_EXT=_C('GLX_SLOW_VISUAL_EXT',0x8001)
GLX_VISUAL_CAVEAT_EXT=_C('GLX_VISUAL_CAVEAT_EXT',0x20)




'''OpenGL extension EXT.draw_buffers

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.draw_buffers to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/draw_buffers.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.draw_buffers import *
from OpenGL.raw.GLES2.EXT.draw_buffers import _EXTENSION_NAME

def glInitDrawBuffersEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy as _lazy

@_lazy( glDrawBuffers )
def glDrawBuffers( baseOperation, n=None, bufs=None ):
    """glDrawBuffers( bufs ) -> bufs

    Wrapper will calculate n from dims of bufs if only
    one argument is provided...
    """
    if bufs is None:
        bufs = n
        n = None
    bufs = arrays.GLenumArray.asArray( bufs )
    if n is None:
        n = arrays.GLenumArray.arraySize( bufs )
    return baseOperation( n,bufs )



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_pixel_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_pixel_texture',error_checker=_errors._error_checker)
GL_PIXEL_TEX_GEN_MODE_SGIX=_C('GL_PIXEL_TEX_GEN_MODE_SGIX',0x832B)
GL_PIXEL_TEX_GEN_SGIX=_C('GL_PIXEL_TEX_GEN_SGIX',0x8139)
@_f
@_p.types(None,_cs.GLenum)
def glPixelTexGenSGIX(mode):pass



'''OpenGL extension SGIX.video_resize

This module customises the behaviour of the 
OpenGL.raw.GLX.SGIX.video_resize to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a means for doing swap or frame synchronous 
	resizing/panning of the area 
	that is to be magnified (or passed through) to the output
	video resolution.  The purpose of this functionality is to provide a
	means of allowing an application to draw into a smaller viewport to
	reduce the time spent doing pixel fill.  This reduced size viewport
	is then magnified up to the video output resolution using the 
	SGIX_video_resize extension.  This extension differs from SGIX_framezoom
	(number 57) in that it is post framebuffer resizing.  Over rendering
	at swap rates and panning at frame rates is possible using frame synchronous
	update instead of swap synchronous update used for the fill reduction case. 

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/video_resize.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGIX.video_resize import *
from OpenGL.raw.GLX.SGIX.video_resize import _EXTENSION_NAME

def glInitVideoResizeSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_4_4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_4_4',error_checker=_errors._error_checker)
GL_BUFFER_IMMUTABLE_STORAGE=_C('GL_BUFFER_IMMUTABLE_STORAGE',0x821F)
GL_BUFFER_STORAGE_FLAGS=_C('GL_BUFFER_STORAGE_FLAGS',0x8220)
GL_CLEAR_TEXTURE=_C('GL_CLEAR_TEXTURE',0x9365)
GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT=_C('GL_CLIENT_MAPPED_BUFFER_BARRIER_BIT',0x00004000)
GL_CLIENT_STORAGE_BIT=_C('GL_CLIENT_STORAGE_BIT',0x0200)
GL_DYNAMIC_STORAGE_BIT=_C('GL_DYNAMIC_STORAGE_BIT',0x0100)
GL_LOCATION_COMPONENT=_C('GL_LOCATION_COMPONENT',0x934A)
GL_MAP_COHERENT_BIT=_C('GL_MAP_COHERENT_BIT',0x0080)
GL_MAP_PERSISTENT_BIT=_C('GL_MAP_PERSISTENT_BIT',0x0040)
GL_MAP_READ_BIT=_C('GL_MAP_READ_BIT',0x0001)
GL_MAP_WRITE_BIT=_C('GL_MAP_WRITE_BIT',0x0002)
GL_MAX_VERTEX_ATTRIB_STRIDE=_C('GL_MAX_VERTEX_ATTRIB_STRIDE',0x82E5)
GL_MIRROR_CLAMP_TO_EDGE=_C('GL_MIRROR_CLAMP_TO_EDGE',0x8743)
GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED=_C('GL_PRIMITIVE_RESTART_FOR_PATCHES_SUPPORTED',0x8221)
GL_QUERY_BUFFER=_C('GL_QUERY_BUFFER',0x9192)
GL_QUERY_BUFFER_BARRIER_BIT=_C('GL_QUERY_BUFFER_BARRIER_BIT',0x00008000)
GL_QUERY_BUFFER_BINDING=_C('GL_QUERY_BUFFER_BINDING',0x9193)
GL_QUERY_RESULT_NO_WAIT=_C('GL_QUERY_RESULT_NO_WAIT',0x9194)
GL_STENCIL_INDEX=_C('GL_STENCIL_INDEX',0x1901)
GL_STENCIL_INDEX8=_C('GL_STENCIL_INDEX8',0x8D48)
GL_TEXTURE_BUFFER_BINDING=_C('GL_TEXTURE_BUFFER_BINDING',0x8C2A)
GL_TRANSFORM_FEEDBACK_BUFFER=_C('GL_TRANSFORM_FEEDBACK_BUFFER',0x8C8E)
GL_TRANSFORM_FEEDBACK_BUFFER_INDEX=_C('GL_TRANSFORM_FEEDBACK_BUFFER_INDEX',0x934B)
GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE=_C('GL_TRANSFORM_FEEDBACK_BUFFER_STRIDE',0x934C)
GL_UNSIGNED_INT_10F_11F_11F_REV=_C('GL_UNSIGNED_INT_10F_11F_11F_REV',0x8C3B)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindBuffersBase(target,first,count,buffers):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,ctypes.POINTER(_cs.GLintptr),ctypes.POINTER(_cs.GLsizeiptr))
def glBindBuffersRange(target,first,count,buffers,offsets,sizes):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindImageTextures(first,count,textures):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindSamplers(first,count,samplers):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindTextures(first,count,textures):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,ctypes.POINTER(_cs.GLintptr),arrays.GLsizeiArray)
def glBindVertexBuffers(first,count,buffers,offsets,strides):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizeiptr,ctypes.c_void_p,_cs.GLbitfield)
def glBufferStorage(target,size,data,flags):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glClearTexImage(texture,level,format,type,data):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glClearTexSubImage(texture,level,xoffset,yoffset,zoffset,width,height,depth,format,type,data):pass



'''OpenGL extension SGIX.clipmap

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.clipmap to provide a more 
Python-friendly API

Overview (from the spec)
	
	Mipmaps provide a general but expensive solution when the texture image
	is very large.  This extension defines clipmaps, which occupy a small
	subset of the memory required by equivalent mipmaps, but provide much
	of the mipmap rendering capabilities.  Clipmaps are especially useful
	for rendering terrain.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/clipmap.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.clipmap import *
from OpenGL.raw.GL.SGIX.clipmap import _EXTENSION_NAME

def glInitClipmapSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_sampler_objects'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_sampler_objects',error_checker=_errors._error_checker)
GL_SAMPLER_BINDING=_C('GL_SAMPLER_BINDING',0x8919)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint)
def glBindSampler(unit,sampler):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteSamplers(count,samplers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenSamplers(count,samplers):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetSamplerParameterIiv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glGetSamplerParameterIuiv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetSamplerParameterfv(sampler,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetSamplerParameteriv(sampler,pname,params):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsSampler(sampler):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glSamplerParameterIiv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLuintArray)
def glSamplerParameterIuiv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLfloat)
def glSamplerParameterf(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glSamplerParameterfv(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,_cs.GLint)
def glSamplerParameteri(sampler,pname,param):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glSamplerParameteriv(sampler,pname,param):pass



'''OpenGL extension ATI.vertex_attrib_array_object

This module customises the behaviour of the 
OpenGL.raw.GL.ATI.vertex_attrib_array_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines an interface that allows multiple sets of
	generic vertex attribute data to be cached in persistent server-side
	memory.  It is intended to allow client data to be stored in memory
	that can be directly accessed by graphics hardware.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ATI/vertex_attrib_array_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ATI.vertex_attrib_array_object import *
from OpenGL.raw.GL.ATI.vertex_attrib_array_object import _EXTENSION_NAME

def glInitVertexAttribArrayObjectATI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetVertexAttribArrayObjectfvATI=wrapper.wrapper(glGetVertexAttribArrayObjectfvATI).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetVertexAttribArrayObjectivATI=wrapper.wrapper(glGetVertexAttribArrayObjectivATI).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.multi_bind

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.multi_bind to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new set of commands allowing applications to
	bind or unbind a set of objects in a single call, instead of requiring a
	separate call for each bind or unbind operation.  Using a single command
	allows OpenGL implementations to amortize function call, name space
	lookup, and potential locking overhead over multiple bind or unbind
	operations.  The rendering loops of graphics applications frequently
	switch between different states, binding different sets of resources,
	including texture objects, sampler objects, textures for image loads and
	stores, uniform buffers, and vertex buffers; this extension provides
	"multi-bind" entry points for all of these object types.
	
	Each command in this extension includes a <first> and <count> parameter,
	specifying a continguous range of binding points to update, as well as an
	array of <count> object names specifying the objects to bind.  Unlike
	single bind commands, multi-bind commands can be used only to bind or
	unbind existing objects.  Passing a previously unused object name
	(generated or not) results in an error and does not create a new object.
	For binding points with associated data (e.g., ranges of a buffer),
	separate arrays are used to pass the associated data for each binding
	point.  Passing zero values in the array of object names removes the
	object bound to the current bounding point.  Additionally, if NULL is
	passed as the array of objects, objects bound to the entire range of
	binding points are unbound, as though the caller passed an array of
	zeroes.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/multi_bind.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.multi_bind import *
from OpenGL.raw.GL.ARB.multi_bind import _EXTENSION_NAME

def glInitMultiBindARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glBindBuffersBase.buffers size not checked against count
glBindBuffersBase=wrapper.wrapper(glBindBuffersBase).setInputArraySize(
    'buffers', None
)
# INPUT glBindBuffersRange.buffers size not checked against count
# INPUT glBindBuffersRange.offsets size not checked against count
# INPUT glBindBuffersRange.sizes size not checked against count
glBindBuffersRange=wrapper.wrapper(glBindBuffersRange).setInputArraySize(
    'buffers', None
).setInputArraySize(
    'offsets', None
).setInputArraySize(
    'sizes', None
)
# INPUT glBindTextures.textures size not checked against count
glBindTextures=wrapper.wrapper(glBindTextures).setInputArraySize(
    'textures', None
)
# INPUT glBindSamplers.samplers size not checked against count
glBindSamplers=wrapper.wrapper(glBindSamplers).setInputArraySize(
    'samplers', None
)
# INPUT glBindImageTextures.textures size not checked against count
glBindImageTextures=wrapper.wrapper(glBindImageTextures).setInputArraySize(
    'textures', None
)
# INPUT glBindVertexBuffers.buffers size not checked against count
# INPUT glBindVertexBuffers.offsets size not checked against count
# INPUT glBindVertexBuffers.strides size not checked against count
glBindVertexBuffers=wrapper.wrapper(glBindVertexBuffers).setInputArraySize(
    'buffers', None
).setInputArraySize(
    'offsets', None
).setInputArraySize(
    'strides', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension SGIS.texture_filter4

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.texture_filter4 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows 1D and 2D textures to be filtered using an
	application-defined, four sample per dimension filter.  (In addition to
	the NEAREST and LINEAR filters defined in the original GL Specification.)
	Such filtering results in higher image quality.  It is defined only
	for non-mipmapped filters.  The filter that is specified must be
	symmetric and separable (in the 2D case).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/texture_filter4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.texture_filter4 import *
from OpenGL.raw.GL.SGIS.texture_filter4 import _EXTENSION_NAME

def glInitTextureFilter4SGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# OUTPUT glGetTexFilterFuncSGIS.weights COMPSIZE(target, filter) 
# INPUT glTexFilterFuncSGIS.weights size not checked against n
glTexFilterFuncSGIS=wrapper.wrapper(glTexFilterFuncSGIS).setInputArraySize(
    'weights', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ATI_fragment_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ATI_fragment_shader',error_checker=_errors._error_checker)
GL_2X_BIT_ATI=_C('GL_2X_BIT_ATI',0x00000001)
GL_4X_BIT_ATI=_C('GL_4X_BIT_ATI',0x00000002)
GL_8X_BIT_ATI=_C('GL_8X_BIT_ATI',0x00000004)
GL_ADD_ATI=_C('GL_ADD_ATI',0x8963)
GL_BIAS_BIT_ATI=_C('GL_BIAS_BIT_ATI',0x00000008)
GL_BLUE_BIT_ATI=_C('GL_BLUE_BIT_ATI',0x00000004)
GL_CND0_ATI=_C('GL_CND0_ATI',0x896B)
GL_CND_ATI=_C('GL_CND_ATI',0x896A)
GL_COLOR_ALPHA_PAIRING_ATI=_C('GL_COLOR_ALPHA_PAIRING_ATI',0x8975)
GL_COMP_BIT_ATI=_C('GL_COMP_BIT_ATI',0x00000002)
GL_CON_0_ATI=_C('GL_CON_0_ATI',0x8941)
GL_CON_10_ATI=_C('GL_CON_10_ATI',0x894B)
GL_CON_11_ATI=_C('GL_CON_11_ATI',0x894C)
GL_CON_12_ATI=_C('GL_CON_12_ATI',0x894D)
GL_CON_13_ATI=_C('GL_CON_13_ATI',0x894E)
GL_CON_14_ATI=_C('GL_CON_14_ATI',0x894F)
GL_CON_15_ATI=_C('GL_CON_15_ATI',0x8950)
GL_CON_16_ATI=_C('GL_CON_16_ATI',0x8951)
GL_CON_17_ATI=_C('GL_CON_17_ATI',0x8952)
GL_CON_18_ATI=_C('GL_CON_18_ATI',0x8953)
GL_CON_19_ATI=_C('GL_CON_19_ATI',0x8954)
GL_CON_1_ATI=_C('GL_CON_1_ATI',0x8942)
GL_CON_20_ATI=_C('GL_CON_20_ATI',0x8955)
GL_CON_21_ATI=_C('GL_CON_21_ATI',0x8956)
GL_CON_22_ATI=_C('GL_CON_22_ATI',0x8957)
GL_CON_23_ATI=_C('GL_CON_23_ATI',0x8958)
GL_CON_24_ATI=_C('GL_CON_24_ATI',0x8959)
GL_CON_25_ATI=_C('GL_CON_25_ATI',0x895A)
GL_CON_26_ATI=_C('GL_CON_26_ATI',0x895B)
GL_CON_27_ATI=_C('GL_CON_27_ATI',0x895C)
GL_CON_28_ATI=_C('GL_CON_28_ATI',0x895D)
GL_CON_29_ATI=_C('GL_CON_29_ATI',0x895E)
GL_CON_2_ATI=_C('GL_CON_2_ATI',0x8943)
GL_CON_30_ATI=_C('GL_CON_30_ATI',0x895F)
GL_CON_31_ATI=_C('GL_CON_31_ATI',0x8960)
GL_CON_3_ATI=_C('GL_CON_3_ATI',0x8944)
GL_CON_4_ATI=_C('GL_CON_4_ATI',0x8945)
GL_CON_5_ATI=_C('GL_CON_5_ATI',0x8946)
GL_CON_6_ATI=_C('GL_CON_6_ATI',0x8947)
GL_CON_7_ATI=_C('GL_CON_7_ATI',0x8948)
GL_CON_8_ATI=_C('GL_CON_8_ATI',0x8949)
GL_CON_9_ATI=_C('GL_CON_9_ATI',0x894A)
GL_DOT2_ADD_ATI=_C('GL_DOT2_ADD_ATI',0x896C)
GL_DOT3_ATI=_C('GL_DOT3_ATI',0x8966)
GL_DOT4_ATI=_C('GL_DOT4_ATI',0x8967)
GL_EIGHTH_BIT_ATI=_C('GL_EIGHTH_BIT_ATI',0x00000020)
GL_FRAGMENT_SHADER_ATI=_C('GL_FRAGMENT_SHADER_ATI',0x8920)
GL_GREEN_BIT_ATI=_C('GL_GREEN_BIT_ATI',0x00000002)
GL_HALF_BIT_ATI=_C('GL_HALF_BIT_ATI',0x00000008)
GL_LERP_ATI=_C('GL_LERP_ATI',0x8969)
GL_MAD_ATI=_C('GL_MAD_ATI',0x8968)
GL_MOV_ATI=_C('GL_MOV_ATI',0x8961)
GL_MUL_ATI=_C('GL_MUL_ATI',0x8964)
GL_NEGATE_BIT_ATI=_C('GL_NEGATE_BIT_ATI',0x00000004)
GL_NUM_FRAGMENT_CONSTANTS_ATI=_C('GL_NUM_FRAGMENT_CONSTANTS_ATI',0x896F)
GL_NUM_FRAGMENT_REGISTERS_ATI=_C('GL_NUM_FRAGMENT_REGISTERS_ATI',0x896E)
GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI=_C('GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI',0x8973)
GL_NUM_INSTRUCTIONS_PER_PASS_ATI=_C('GL_NUM_INSTRUCTIONS_PER_PASS_ATI',0x8971)
GL_NUM_INSTRUCTIONS_TOTAL_ATI=_C('GL_NUM_INSTRUCTIONS_TOTAL_ATI',0x8972)
GL_NUM_LOOPBACK_COMPONENTS_ATI=_C('GL_NUM_LOOPBACK_COMPONENTS_ATI',0x8974)
GL_NUM_PASSES_ATI=_C('GL_NUM_PASSES_ATI',0x8970)
GL_QUARTER_BIT_ATI=_C('GL_QUARTER_BIT_ATI',0x00000010)
GL_RED_BIT_ATI=_C('GL_RED_BIT_ATI',0x00000001)
GL_REG_0_ATI=_C('GL_REG_0_ATI',0x8921)
GL_REG_10_ATI=_C('GL_REG_10_ATI',0x892B)
GL_REG_11_ATI=_C('GL_REG_11_ATI',0x892C)
GL_REG_12_ATI=_C('GL_REG_12_ATI',0x892D)
GL_REG_13_ATI=_C('GL_REG_13_ATI',0x892E)
GL_REG_14_ATI=_C('GL_REG_14_ATI',0x892F)
GL_REG_15_ATI=_C('GL_REG_15_ATI',0x8930)
GL_REG_16_ATI=_C('GL_REG_16_ATI',0x8931)
GL_REG_17_ATI=_C('GL_REG_17_ATI',0x8932)
GL_REG_18_ATI=_C('GL_REG_18_ATI',0x8933)
GL_REG_19_ATI=_C('GL_REG_19_ATI',0x8934)
GL_REG_1_ATI=_C('GL_REG_1_ATI',0x8922)
GL_REG_20_ATI=_C('GL_REG_20_ATI',0x8935)
GL_REG_21_ATI=_C('GL_REG_21_ATI',0x8936)
GL_REG_22_ATI=_C('GL_REG_22_ATI',0x8937)
GL_REG_23_ATI=_C('GL_REG_23_ATI',0x8938)
GL_REG_24_ATI=_C('GL_REG_24_ATI',0x8939)
GL_REG_25_ATI=_C('GL_REG_25_ATI',0x893A)
GL_REG_26_ATI=_C('GL_REG_26_ATI',0x893B)
GL_REG_27_ATI=_C('GL_REG_27_ATI',0x893C)
GL_REG_28_ATI=_C('GL_REG_28_ATI',0x893D)
GL_REG_29_ATI=_C('GL_REG_29_ATI',0x893E)
GL_REG_2_ATI=_C('GL_REG_2_ATI',0x8923)
GL_REG_30_ATI=_C('GL_REG_30_ATI',0x893F)
GL_REG_31_ATI=_C('GL_REG_31_ATI',0x8940)
GL_REG_3_ATI=_C('GL_REG_3_ATI',0x8924)
GL_REG_4_ATI=_C('GL_REG_4_ATI',0x8925)
GL_REG_5_ATI=_C('GL_REG_5_ATI',0x8926)
GL_REG_6_ATI=_C('GL_REG_6_ATI',0x8927)
GL_REG_7_ATI=_C('GL_REG_7_ATI',0x8928)
GL_REG_8_ATI=_C('GL_REG_8_ATI',0x8929)
GL_REG_9_ATI=_C('GL_REG_9_ATI',0x892A)
GL_SATURATE_BIT_ATI=_C('GL_SATURATE_BIT_ATI',0x00000040)
GL_SECONDARY_INTERPOLATOR_ATI=_C('GL_SECONDARY_INTERPOLATOR_ATI',0x896D)
GL_SUB_ATI=_C('GL_SUB_ATI',0x8965)
GL_SWIZZLE_STQ_ATI=_C('GL_SWIZZLE_STQ_ATI',0x8977)
GL_SWIZZLE_STQ_DQ_ATI=_C('GL_SWIZZLE_STQ_DQ_ATI',0x8979)
GL_SWIZZLE_STRQ_ATI=_C('GL_SWIZZLE_STRQ_ATI',0x897A)
GL_SWIZZLE_STRQ_DQ_ATI=_C('GL_SWIZZLE_STRQ_DQ_ATI',0x897B)
GL_SWIZZLE_STR_ATI=_C('GL_SWIZZLE_STR_ATI',0x8976)
GL_SWIZZLE_STR_DR_ATI=_C('GL_SWIZZLE_STR_DR_ATI',0x8978)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glAlphaFragmentOp1ATI(op,dst,dstMod,arg1,arg1Rep,arg1Mod):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glAlphaFragmentOp2ATI(op,dst,dstMod,arg1,arg1Rep,arg1Mod,arg2,arg2Rep,arg2Mod):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glAlphaFragmentOp3ATI(op,dst,dstMod,arg1,arg1Rep,arg1Mod,arg2,arg2Rep,arg2Mod,arg3,arg3Rep,arg3Mod):pass
@_f
@_p.types(None,)
def glBeginFragmentShaderATI():pass
@_f
@_p.types(None,_cs.GLuint)
def glBindFragmentShaderATI(id):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColorFragmentOp1ATI(op,dst,dstMask,dstMod,arg1,arg1Rep,arg1Mod):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColorFragmentOp2ATI(op,dst,dstMask,dstMod,arg1,arg1Rep,arg1Mod,arg2,arg2Rep,arg2Mod):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glColorFragmentOp3ATI(op,dst,dstMask,dstMod,arg1,arg1Rep,arg1Mod,arg2,arg2Rep,arg2Mod,arg3,arg3Rep,arg3Mod):pass
@_f
@_p.types(None,_cs.GLuint)
def glDeleteFragmentShaderATI(id):pass
@_f
@_p.types(None,)
def glEndFragmentShaderATI():pass
@_f
@_p.types(_cs.GLuint,_cs.GLuint)
def glGenFragmentShadersATI(range):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum)
def glPassTexCoordATI(dst,coord,swizzle):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum)
def glSampleMapATI(dst,interp,swizzle):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glSetFragmentShaderConstantATI(dst,value):pass



'''OpenGL extension NV.float_buffer

This module customises the behaviour of the 
OpenGL.raw.GLX.NV.float_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension builds upon NV_fragment_program to provide a framebuffer
	and texture format that allows fragment programs to read and write
	unconstrained floating point data.
	
	In unextended OpenGL, most computations dealing with color or depth
	buffers are typically constrained to operate on values in the range [0,1].
	Computational results are also typically clamped to the range [0,1].
	Color, texture, and depth buffers themselves also hold values mapped to
	the range [0,1].
	
	The NV_fragment_program extension provides a general computational model
	that supports floating-point numbers constrained only by the precision of
	the underlying data types.  The quantites computed by fragment programs do
	not necessarily correspond in number or in range to conventional
	attributes such as RGBA colors or depth values.  Because of the range and
	precision constraints imposed by conventional fixed-point color buffers,
	it may be difficult (if not impossible) to use them to implement certain
	multi-pass algorithms.
	
	To enhance the extended range and precision available through fragment
	programs, this extension provides floating-point RGBA color buffers that
	can be used instead of conventional fixed-point RGBA color buffers.  A
	floating-point RGBA color buffer consists of one to four floating-point
	components stored in the 16- or 32-bit floating-point formats (fp16 or
	fp32) defined in the NV_half_float and NV_fragment_program extensions.
	
	When a floating-point color buffer is used, the results of fragment
	programs, as written to the "x", "y", "z", and "w" components of the
	o[COLR] or o[COLH] output registers, are written directly to the color
	buffer without any clamping or modification.  Certain per-fragment
	operations are bypassed when rendering to floating-point color buffers.
	
	A floating-point color buffer can also be used as a texture map, either by
	reading back the contents and then using conventional TexImage calls, or
	by using the buffer directly via the ARB_render_texture extension or
	the EXT_framebuffer_object extension.
	
	This extension has many uses.  Some possible uses include:
	
	    (1) Multi-pass algorithms with arbitrary intermediate results that
	        don't have to be artifically forced into the range [0,1].  In
	        addition, intermediate results can be written without having to
	        worry about out-of-range values.
	
	    (2) Deferred shading algorithms where an expensive fragment program is
	        executed only after depth testing is fully complete.  Instead, a
	        simple program is executed, which stores the parameters necessary
	        to produce a final result.  After the entire scene is rendered, a
	        second pass is executed over the entire frame buffer to execute
	        the complex fragment program using the results written to the
	        floating-point color buffer in the first pass.  This will save the
	        cost of applying complex fragment programs to fragments that will
	        not appear in the final image.
	
	    (3) Use floating-point texture maps to evaluate functions with
	        arbitrary ranges.  Arbitrary functions with a finite domain can be
	        approximated using a texture map holding sample results and
	        piecewise linear approximation.
	
	There are several significant limitations on the use of floating-point
	color buffers.  First, floating-point color buffers do not support frame
	buffer blending.  Second, floating-point texture maps do not support
	mipmapping or any texture filtering other than NEAREST.  Third,
	floating-point texture maps must be 2D, and must use the
	NV_texture_rectangle extension.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/float_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.NV.float_buffer import *
from OpenGL.raw.GLX.NV.float_buffer import _EXTENSION_NAME

def glInitFloatBufferNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.internalformat_query2

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.internalformat_query2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the GetInternalformativ query that was added in
	the ARB_internalformat_query extension to provide applications with more 
	granular per-format capability information.
	
	This extension allows the remainder of the texture-style targets to
	be specified along with any possible internal format. 
	We add queries for additional properties supported for an internal
	format in addition to the multisample-related information that was
	added in ARB_internalformat_query.
	
	The goals of this extension are to: 
	
	a) provide a mechanism for implementations to declare support *above* the
	   minimum required by the specification
	
	b) provide API to allow universally constant information to be queried
	
	c) provide a user-friendly way of finding out about version- or 
	   implementation-specific limitations. 
	
	While much of this information can be determined for a single GL version
	by careful examination of the specification, support for many of these 
	properties has been gradually introduced over a number of API
	revisions. This can observed when considering the range in functionality
	between the various versions of GL 2, 3, and 4, as well as GL ES 2 and 3.
	
	In the case of an application which wishes to be scalable and able to run
	on a variety of possible GL or GL ES versions without being specifically
	tailored for each version, it must either have knowledge of the
	specifications built up into either the code or tables, or it must do
	a number of tests on startup to determine which capabilities are present.
	
	In OpenGL, other than the course-grained extension mechanism, many 
	limitations of, or limited support for, an internalformat can only 
	be signaled by failing an operation or by operating at reduced
	performance.  Thus, such tests often involve attempts to create resources,
	using them in specific ways and benchmarking the operations to
	find out if it is supported in the desired form, and at a required 
	performance level. The extension provides a way for these properties
	and caveats to be directly queried from the implementation.
	
	This extension is NOT intended to allow implementations to only support
	a subset of features that are required by a specific GL version, nor is
	it intended to replace the proper use of extension checks for optional
	functionality.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/internalformat_query2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.internalformat_query2 import *
from OpenGL.raw.GL.ARB.internalformat_query2 import _EXTENSION_NAME

def glInitInternalformatQuery2ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetInternalformati64v=wrapper.wrapper(glGetInternalformati64v).setOutput(
    'params',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_geometry_program4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_geometry_program4',error_checker=_errors._error_checker)
GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_LAYERED_EXT',0x8DA7)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER_EXT',0x8CD4)
GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_LAYER_COUNT_EXT',0x8DA9)
GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT=_C('GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_EXT',0x8DA8)
GL_GEOMETRY_INPUT_TYPE_EXT=_C('GL_GEOMETRY_INPUT_TYPE_EXT',0x8DDB)
GL_GEOMETRY_OUTPUT_TYPE_EXT=_C('GL_GEOMETRY_OUTPUT_TYPE_EXT',0x8DDC)
GL_GEOMETRY_PROGRAM_NV=_C('GL_GEOMETRY_PROGRAM_NV',0x8C26)
GL_GEOMETRY_VERTICES_OUT_EXT=_C('GL_GEOMETRY_VERTICES_OUT_EXT',0x8DDA)
GL_LINES_ADJACENCY_EXT=_C('GL_LINES_ADJACENCY_EXT',0x000A)
GL_LINE_STRIP_ADJACENCY_EXT=_C('GL_LINE_STRIP_ADJACENCY_EXT',0x000B)
GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT=_C('GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_EXT',0x8C29)
GL_MAX_PROGRAM_OUTPUT_VERTICES_NV=_C('GL_MAX_PROGRAM_OUTPUT_VERTICES_NV',0x8C27)
GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV=_C('GL_MAX_PROGRAM_TOTAL_OUTPUT_COMPONENTS_NV',0x8C28)
GL_PROGRAM_POINT_SIZE_EXT=_C('GL_PROGRAM_POINT_SIZE_EXT',0x8642)
GL_TRIANGLES_ADJACENCY_EXT=_C('GL_TRIANGLES_ADJACENCY_EXT',0x000C)
GL_TRIANGLE_STRIP_ADJACENCY_EXT=_C('GL_TRIANGLE_STRIP_ADJACENCY_EXT',0x000D)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTextureEXT(target,attachment,texture,level):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLenum)
def glFramebufferTextureFaceEXT(target,attachment,texture,level,face):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTextureLayerEXT(target,attachment,texture,level,layer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glProgramVertexLimitNV(target,limit):pass



'''OpenGL extension APPLE.specular_vector

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.specular_vector to provide a more 
Python-friendly API

Overview (from the spec)
	
	An alternative specular lighting model is enabled by passing
	the LIGHT_MODEL_SPECULAR_VECTOR token as the <pname> parameter
	to LightModel, and TRUE as the <param> parameter.  The specular
	vector lighting model calculates the specular intensity as the
	dot product of the true reflection vector of the light source
	and the vector from the vertex to the viewpoint.  This yields
	results that are visually similar to but often more realistic
	than the existing lighting model.  
	
	Mathematically, the specular component s.n in the existing
	lighting model calculation is replaced with the following
	alternative calculation.
	
	Given three vectors, n, l, and p, where n is the unit normal
	vector at the vertex, l is the unit vector from the vertex to
	the light position, and p is the unit vector from the vertex
	to the viewpoint (or the vector {0,0,1} if
	LIGHT_MODEL_LOCAL_VIEWER is false), the specular component is
	given by
	
	  (2 * cross(n, cross(n, l)) + l) . p
	
	All other lighting model and material parameters (shininess,
	spotlight, attenuation, local viewer, and direction/positional
	sources) operate normally.  The specular vector lighting model
	affects both rgba and index modes.   

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/specular_vector.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.specular_vector import *
from OpenGL.raw.GL.APPLE.specular_vector import _EXTENSION_NAME

def glInitSpecularVectorAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION



'''OpenGL extension SGIS.sharpen_texture

This module customises the behaviour of the 
OpenGL.raw.GL.SGIS.sharpen_texture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces texture magnification filters that sharpen
	the resulting image by extrapolating from the level 1 image to the
	level 0 image.  Sharpening can be enabled for all color channels, for
	the alpha channel only, or for the red, green, and blue channels only.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIS/sharpen_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIS.sharpen_texture import *
from OpenGL.raw.GL.SGIS.sharpen_texture import _EXTENSION_NAME

def glInitSharpenTextureSGIS():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glSharpenTexFuncSGIS.points size not checked against n*2
glSharpenTexFuncSGIS=wrapper.wrapper(glSharpenTexFuncSGIS).setInputArraySize(
    'points', None
)
glGetSharpenTexFuncSGIS=wrapper.wrapper(glGetSharpenTexFuncSGIS).setOutput(
    'points',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_EXT_pixel_format'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_EXT_pixel_format',error_checker=_errors._error_checker)
WGL_ACCELERATION_EXT=_C('WGL_ACCELERATION_EXT',0x2003)
WGL_ACCUM_ALPHA_BITS_EXT=_C('WGL_ACCUM_ALPHA_BITS_EXT',0x2021)
WGL_ACCUM_BITS_EXT=_C('WGL_ACCUM_BITS_EXT',0x201D)
WGL_ACCUM_BLUE_BITS_EXT=_C('WGL_ACCUM_BLUE_BITS_EXT',0x2020)
WGL_ACCUM_GREEN_BITS_EXT=_C('WGL_ACCUM_GREEN_BITS_EXT',0x201F)
WGL_ACCUM_RED_BITS_EXT=_C('WGL_ACCUM_RED_BITS_EXT',0x201E)
WGL_ALPHA_BITS_EXT=_C('WGL_ALPHA_BITS_EXT',0x201B)
WGL_ALPHA_SHIFT_EXT=_C('WGL_ALPHA_SHIFT_EXT',0x201C)
WGL_AUX_BUFFERS_EXT=_C('WGL_AUX_BUFFERS_EXT',0x2024)
WGL_BLUE_BITS_EXT=_C('WGL_BLUE_BITS_EXT',0x2019)
WGL_BLUE_SHIFT_EXT=_C('WGL_BLUE_SHIFT_EXT',0x201A)
WGL_COLOR_BITS_EXT=_C('WGL_COLOR_BITS_EXT',0x2014)
WGL_DEPTH_BITS_EXT=_C('WGL_DEPTH_BITS_EXT',0x2022)
WGL_DOUBLE_BUFFER_EXT=_C('WGL_DOUBLE_BUFFER_EXT',0x2011)
WGL_DRAW_TO_BITMAP_EXT=_C('WGL_DRAW_TO_BITMAP_EXT',0x2002)
WGL_DRAW_TO_WINDOW_EXT=_C('WGL_DRAW_TO_WINDOW_EXT',0x2001)
WGL_FULL_ACCELERATION_EXT=_C('WGL_FULL_ACCELERATION_EXT',0x2027)
WGL_GENERIC_ACCELERATION_EXT=_C('WGL_GENERIC_ACCELERATION_EXT',0x2026)
WGL_GREEN_BITS_EXT=_C('WGL_GREEN_BITS_EXT',0x2017)
WGL_GREEN_SHIFT_EXT=_C('WGL_GREEN_SHIFT_EXT',0x2018)
WGL_NEED_PALETTE_EXT=_C('WGL_NEED_PALETTE_EXT',0x2004)
WGL_NEED_SYSTEM_PALETTE_EXT=_C('WGL_NEED_SYSTEM_PALETTE_EXT',0x2005)
WGL_NO_ACCELERATION_EXT=_C('WGL_NO_ACCELERATION_EXT',0x2025)
WGL_NUMBER_OVERLAYS_EXT=_C('WGL_NUMBER_OVERLAYS_EXT',0x2008)
WGL_NUMBER_PIXEL_FORMATS_EXT=_C('WGL_NUMBER_PIXEL_FORMATS_EXT',0x2000)
WGL_NUMBER_UNDERLAYS_EXT=_C('WGL_NUMBER_UNDERLAYS_EXT',0x2009)
WGL_PIXEL_TYPE_EXT=_C('WGL_PIXEL_TYPE_EXT',0x2013)
WGL_RED_BITS_EXT=_C('WGL_RED_BITS_EXT',0x2015)
WGL_RED_SHIFT_EXT=_C('WGL_RED_SHIFT_EXT',0x2016)
WGL_SHARE_ACCUM_EXT=_C('WGL_SHARE_ACCUM_EXT',0x200E)
WGL_SHARE_DEPTH_EXT=_C('WGL_SHARE_DEPTH_EXT',0x200C)
WGL_SHARE_STENCIL_EXT=_C('WGL_SHARE_STENCIL_EXT',0x200D)
WGL_STENCIL_BITS_EXT=_C('WGL_STENCIL_BITS_EXT',0x2023)
WGL_STEREO_EXT=_C('WGL_STEREO_EXT',0x2012)
WGL_SUPPORT_GDI_EXT=_C('WGL_SUPPORT_GDI_EXT',0x200F)
WGL_SUPPORT_OPENGL_EXT=_C('WGL_SUPPORT_OPENGL_EXT',0x2010)
WGL_SWAP_COPY_EXT=_C('WGL_SWAP_COPY_EXT',0x2029)
WGL_SWAP_EXCHANGE_EXT=_C('WGL_SWAP_EXCHANGE_EXT',0x2028)
WGL_SWAP_LAYER_BUFFERS_EXT=_C('WGL_SWAP_LAYER_BUFFERS_EXT',0x2006)
WGL_SWAP_METHOD_EXT=_C('WGL_SWAP_METHOD_EXT',0x2007)
WGL_SWAP_UNDEFINED_EXT=_C('WGL_SWAP_UNDEFINED_EXT',0x202A)
WGL_TRANSPARENT_EXT=_C('WGL_TRANSPARENT_EXT',0x200A)
WGL_TRANSPARENT_VALUE_EXT=_C('WGL_TRANSPARENT_VALUE_EXT',0x200B)
WGL_TYPE_COLORINDEX_EXT=_C('WGL_TYPE_COLORINDEX_EXT',0x202C)
WGL_TYPE_RGBA_EXT=_C('WGL_TYPE_RGBA_EXT',0x202B)
@_f
@_p.types(_cs.BOOL,_cs.HDC,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.FLOAT),_cs.UINT,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.UINT))
def wglChoosePixelFormatEXT(hdc,piAttribIList,pfAttribFList,nMaxFormats,piFormats,nNumFormats):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,_cs.c_int,_cs.UINT,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.FLOAT))
def wglGetPixelFormatAttribfvEXT(hdc,iPixelFormat,iLayerPlane,nAttributes,piAttributes,pfValues):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.c_int,_cs.c_int,_cs.UINT,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def wglGetPixelFormatAttribivEXT(hdc,iPixelFormat,iLayerPlane,nAttributes,piAttributes,piValues):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_imaging'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_imaging',error_checker=_errors._error_checker)
GL_BLEND_COLOR=_C('GL_BLEND_COLOR',0x8005)
GL_BLEND_EQUATION=_C('GL_BLEND_EQUATION',0x8009)
GL_COLOR_MATRIX=_C('GL_COLOR_MATRIX',0x80B1)
GL_COLOR_MATRIX_STACK_DEPTH=_C('GL_COLOR_MATRIX_STACK_DEPTH',0x80B2)
GL_COLOR_TABLE=_C('GL_COLOR_TABLE',0x80D0)
GL_COLOR_TABLE_ALPHA_SIZE=_C('GL_COLOR_TABLE_ALPHA_SIZE',0x80DD)
GL_COLOR_TABLE_BIAS=_C('GL_COLOR_TABLE_BIAS',0x80D7)
GL_COLOR_TABLE_BLUE_SIZE=_C('GL_COLOR_TABLE_BLUE_SIZE',0x80DC)
GL_COLOR_TABLE_FORMAT=_C('GL_COLOR_TABLE_FORMAT',0x80D8)
GL_COLOR_TABLE_GREEN_SIZE=_C('GL_COLOR_TABLE_GREEN_SIZE',0x80DB)
GL_COLOR_TABLE_INTENSITY_SIZE=_C('GL_COLOR_TABLE_INTENSITY_SIZE',0x80DF)
GL_COLOR_TABLE_LUMINANCE_SIZE=_C('GL_COLOR_TABLE_LUMINANCE_SIZE',0x80DE)
GL_COLOR_TABLE_RED_SIZE=_C('GL_COLOR_TABLE_RED_SIZE',0x80DA)
GL_COLOR_TABLE_SCALE=_C('GL_COLOR_TABLE_SCALE',0x80D6)
GL_COLOR_TABLE_WIDTH=_C('GL_COLOR_TABLE_WIDTH',0x80D9)
GL_CONSTANT_ALPHA=_C('GL_CONSTANT_ALPHA',0x8003)
GL_CONSTANT_BORDER=_C('GL_CONSTANT_BORDER',0x8151)
GL_CONSTANT_COLOR=_C('GL_CONSTANT_COLOR',0x8001)
GL_CONVOLUTION_1D=_C('GL_CONVOLUTION_1D',0x8010)
GL_CONVOLUTION_2D=_C('GL_CONVOLUTION_2D',0x8011)
GL_CONVOLUTION_BORDER_COLOR=_C('GL_CONVOLUTION_BORDER_COLOR',0x8154)
GL_CONVOLUTION_BORDER_MODE=_C('GL_CONVOLUTION_BORDER_MODE',0x8013)
GL_CONVOLUTION_FILTER_BIAS=_C('GL_CONVOLUTION_FILTER_BIAS',0x8015)
GL_CONVOLUTION_FILTER_SCALE=_C('GL_CONVOLUTION_FILTER_SCALE',0x8014)
GL_CONVOLUTION_FORMAT=_C('GL_CONVOLUTION_FORMAT',0x8017)
GL_CONVOLUTION_HEIGHT=_C('GL_CONVOLUTION_HEIGHT',0x8019)
GL_CONVOLUTION_WIDTH=_C('GL_CONVOLUTION_WIDTH',0x8018)
GL_FUNC_ADD=_C('GL_FUNC_ADD',0x8006)
GL_FUNC_REVERSE_SUBTRACT=_C('GL_FUNC_REVERSE_SUBTRACT',0x800B)
GL_FUNC_SUBTRACT=_C('GL_FUNC_SUBTRACT',0x800A)
GL_HISTOGRAM=_C('GL_HISTOGRAM',0x8024)
GL_HISTOGRAM_ALPHA_SIZE=_C('GL_HISTOGRAM_ALPHA_SIZE',0x802B)
GL_HISTOGRAM_BLUE_SIZE=_C('GL_HISTOGRAM_BLUE_SIZE',0x802A)
GL_HISTOGRAM_FORMAT=_C('GL_HISTOGRAM_FORMAT',0x8027)
GL_HISTOGRAM_GREEN_SIZE=_C('GL_HISTOGRAM_GREEN_SIZE',0x8029)
GL_HISTOGRAM_LUMINANCE_SIZE=_C('GL_HISTOGRAM_LUMINANCE_SIZE',0x802C)
GL_HISTOGRAM_RED_SIZE=_C('GL_HISTOGRAM_RED_SIZE',0x8028)
GL_HISTOGRAM_SINK=_C('GL_HISTOGRAM_SINK',0x802D)
GL_HISTOGRAM_WIDTH=_C('GL_HISTOGRAM_WIDTH',0x8026)
GL_MAX=_C('GL_MAX',0x8008)
GL_MAX_COLOR_MATRIX_STACK_DEPTH=_C('GL_MAX_COLOR_MATRIX_STACK_DEPTH',0x80B3)
GL_MAX_CONVOLUTION_HEIGHT=_C('GL_MAX_CONVOLUTION_HEIGHT',0x801B)
GL_MAX_CONVOLUTION_WIDTH=_C('GL_MAX_CONVOLUTION_WIDTH',0x801A)
GL_MIN=_C('GL_MIN',0x8007)
GL_MINMAX=_C('GL_MINMAX',0x802E)
GL_MINMAX_FORMAT=_C('GL_MINMAX_FORMAT',0x802F)
GL_MINMAX_SINK=_C('GL_MINMAX_SINK',0x8030)
GL_ONE_MINUS_CONSTANT_ALPHA=_C('GL_ONE_MINUS_CONSTANT_ALPHA',0x8004)
GL_ONE_MINUS_CONSTANT_COLOR=_C('GL_ONE_MINUS_CONSTANT_COLOR',0x8002)
GL_POST_COLOR_MATRIX_ALPHA_BIAS=_C('GL_POST_COLOR_MATRIX_ALPHA_BIAS',0x80BB)
GL_POST_COLOR_MATRIX_ALPHA_SCALE=_C('GL_POST_COLOR_MATRIX_ALPHA_SCALE',0x80B7)
GL_POST_COLOR_MATRIX_BLUE_BIAS=_C('GL_POST_COLOR_MATRIX_BLUE_BIAS',0x80BA)
GL_POST_COLOR_MATRIX_BLUE_SCALE=_C('GL_POST_COLOR_MATRIX_BLUE_SCALE',0x80B6)
GL_POST_COLOR_MATRIX_COLOR_TABLE=_C('GL_POST_COLOR_MATRIX_COLOR_TABLE',0x80D2)
GL_POST_COLOR_MATRIX_GREEN_BIAS=_C('GL_POST_COLOR_MATRIX_GREEN_BIAS',0x80B9)
GL_POST_COLOR_MATRIX_GREEN_SCALE=_C('GL_POST_COLOR_MATRIX_GREEN_SCALE',0x80B5)
GL_POST_COLOR_MATRIX_RED_BIAS=_C('GL_POST_COLOR_MATRIX_RED_BIAS',0x80B8)
GL_POST_COLOR_MATRIX_RED_SCALE=_C('GL_POST_COLOR_MATRIX_RED_SCALE',0x80B4)
GL_POST_CONVOLUTION_ALPHA_BIAS=_C('GL_POST_CONVOLUTION_ALPHA_BIAS',0x8023)
GL_POST_CONVOLUTION_ALPHA_SCALE=_C('GL_POST_CONVOLUTION_ALPHA_SCALE',0x801F)
GL_POST_CONVOLUTION_BLUE_BIAS=_C('GL_POST_CONVOLUTION_BLUE_BIAS',0x8022)
GL_POST_CONVOLUTION_BLUE_SCALE=_C('GL_POST_CONVOLUTION_BLUE_SCALE',0x801E)
GL_POST_CONVOLUTION_COLOR_TABLE=_C('GL_POST_CONVOLUTION_COLOR_TABLE',0x80D1)
GL_POST_CONVOLUTION_GREEN_BIAS=_C('GL_POST_CONVOLUTION_GREEN_BIAS',0x8021)
GL_POST_CONVOLUTION_GREEN_SCALE=_C('GL_POST_CONVOLUTION_GREEN_SCALE',0x801D)
GL_POST_CONVOLUTION_RED_BIAS=_C('GL_POST_CONVOLUTION_RED_BIAS',0x8020)
GL_POST_CONVOLUTION_RED_SCALE=_C('GL_POST_CONVOLUTION_RED_SCALE',0x801C)
GL_PROXY_COLOR_TABLE=_C('GL_PROXY_COLOR_TABLE',0x80D3)
GL_PROXY_HISTOGRAM=_C('GL_PROXY_HISTOGRAM',0x8025)
GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE=_C('GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE',0x80D5)
GL_PROXY_POST_CONVOLUTION_COLOR_TABLE=_C('GL_PROXY_POST_CONVOLUTION_COLOR_TABLE',0x80D4)
GL_REDUCE=_C('GL_REDUCE',0x8016)
GL_REPLICATE_BORDER=_C('GL_REPLICATE_BORDER',0x8153)
GL_SEPARABLE_2D=_C('GL_SEPARABLE_2D',0x8012)
GL_TABLE_TOO_LARGE=_C('GL_TABLE_TOO_LARGE',0x8031)
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glBlendColor(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLenum)
def glBlendEquation(mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glColorSubTable(target,start,count,format,type,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glColorTable(target,internalformat,width,format,type,table):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glColorTableParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glColorTableParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glConvolutionFilter1D(target,internalformat,width,format,type,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glConvolutionFilter2D(target,internalformat,width,height,format,type,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glConvolutionParameterf(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glConvolutionParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glConvolutionParameteri(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glConvolutionParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyColorSubTable(target,start,x,y,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyColorTable(target,internalformat,x,y,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyConvolutionFilter1D(target,internalformat,x,y,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyConvolutionFilter2D(target,internalformat,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetColorTable(target,format,type,table):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetColorTableParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetColorTableParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetConvolutionFilter(target,format,type,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetConvolutionParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetConvolutionParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLboolean,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetHistogram(target,reset,format,type,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetHistogramParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetHistogramParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLboolean,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetMinmax(target,reset,format,type,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMinmaxParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetMinmaxParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p,ctypes.c_void_p,ctypes.c_void_p)
def glGetSeparableFilter(target,format,type,row,column,span):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLboolean)
def glHistogram(target,width,internalformat,sink):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLboolean)
def glMinmax(target,internalformat,sink):pass
@_f
@_p.types(None,_cs.GLenum)
def glResetHistogram(target):pass
@_f
@_p.types(None,_cs.GLenum)
def glResetMinmax(target):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p,ctypes.c_void_p)
def glSeparableFilter2D(target,internalformat,width,height,format,type,row,column):pass



'''OpenGL extension ARB.stencil_texturing

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.stencil_texturing to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows texturing of the stencil component of a packed depth
	stencil texture. Stencil values are returned as unsigned integers. It is
	not possible to sample both depth and stencil values from the same
	texture, and this extension allows the app to select which is sampled for
	the bound texture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/stencil_texturing.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.stencil_texturing import *
from OpenGL.raw.GL.ARB.stencil_texturing import _EXTENSION_NAME

def glInitStencilTexturingARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_NV_stream_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_NV_stream_sync',error_checker=_errors._error_checker)
EGL_SYNC_NEW_FRAME_NV=_C('EGL_SYNC_NEW_FRAME_NV',0x321F)
EGL_SYNC_TYPE_KHR=_C('EGL_SYNC_TYPE_KHR',0x30F7)
@_f
@_p.types(_cs.EGLSyncKHR,_cs.EGLDisplay,_cs.EGLStreamKHR,_cs.EGLenum,arrays.GLintArray)
def eglCreateStreamSyncNV(dpy,stream,type,attrib_list):pass



'''OpenGL extension OES.texture_border_clamp

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.texture_border_clamp to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/texture_border_clamp.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.texture_border_clamp import *
from OpenGL.raw.GLES2.OES.texture_border_clamp import _EXTENSION_NAME

def glInitTextureBorderClampOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glTexParameterIivOES.params size not checked against 'pname'
glTexParameterIivOES=wrapper.wrapper(glTexParameterIivOES).setInputArraySize(
    'params', None
)
# INPUT glTexParameterIuivOES.params size not checked against 'pname'
glTexParameterIuivOES=wrapper.wrapper(glTexParameterIuivOES).setInputArraySize(
    'params', None
)
# INPUT glGetTexParameterIivOES.params size not checked against 'pname'
glGetTexParameterIivOES=wrapper.wrapper(glGetTexParameterIivOES).setInputArraySize(
    'params', None
)
# INPUT glGetTexParameterIuivOES.params size not checked against 'pname'
glGetTexParameterIuivOES=wrapper.wrapper(glGetTexParameterIuivOES).setInputArraySize(
    'params', None
)
# INPUT glSamplerParameterIivOES.param size not checked against 'pname'
glSamplerParameterIivOES=wrapper.wrapper(glSamplerParameterIivOES).setInputArraySize(
    'param', None
)
# INPUT glSamplerParameterIuivOES.param size not checked against 'pname'
glSamplerParameterIuivOES=wrapper.wrapper(glSamplerParameterIuivOES).setInputArraySize(
    'param', None
)
# INPUT glGetSamplerParameterIivOES.params size not checked against 'pname'
glGetSamplerParameterIivOES=wrapper.wrapper(glGetSamplerParameterIivOES).setInputArraySize(
    'params', None
)
# INPUT glGetSamplerParameterIuivOES.params size not checked against 'pname'
glGetSamplerParameterIuivOES=wrapper.wrapper(glGetSamplerParameterIuivOES).setInputArraySize(
    'params', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_AMD_compressed_ATC_texture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_AMD_compressed_ATC_texture',error_checker=_errors._error_checker)
GL_ATC_RGBA_EXPLICIT_ALPHA_AMD=_C('GL_ATC_RGBA_EXPLICIT_ALPHA_AMD',0x8C93)
GL_ATC_RGBA_INTERPOLATED_ALPHA_AMD=_C('GL_ATC_RGBA_INTERPOLATED_ALPHA_AMD',0x87EE)
GL_ATC_RGB_AMD=_C('GL_ATC_RGB_AMD',0x8C92)




'''OpenGL extension EXT.stencil_clear_tag

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.stencil_clear_tag to provide a more 
Python-friendly API

Overview (from the spec)
	
	Stencil-only framebuffer clears are increasingly common as 3D
	applications are now using rendering algorithms such as stenciled
	shadow volume rendering for multiple light sources in a single frame,
	recent "soft" stenciled shadow volume techniques, and stencil-based
	constructive solid geometry techniques.  In such algorithms there
	are multiple stencil buffer clears for each depth buffer clear.
	Additionally in most cases, these algorithms do not require all
	of the 8 typical stencil bitplanes for their stencil requirements.
	In such cases, there is the potential for unused stencil bitplanes
	to encode a "stencil clear tag" in such a way to reduce the number
	of actual stencil clears.  The idea is that switching to an unused
	stencil clear tag logically corresponds to when an application would
	otherwise perform a framebuffer-wide stencil clear.
	
	This extension exposes an inexpensive hardware mechanism for
	amortizing the cost of multiple stencil-only clears by using a
	client-specified number of upper bits of the stencil buffer to
	maintain a per-pixel stencil tag.
	
	The upper bits of each stencil value is treated as a tag that
	indicates the state of the upper bits of the "stencil clear tag" state
	when the stencil value was last written.  If a stencil value is read
	and its upper bits containing its tag do NOT match the current upper
	bits of the stencil clear tag state, the stencil value is substituted
	with the lower bits of the stencil clear tag (the reset value).
	Either way, the upper tag bits of the stencil value are ignored by
	subsequent stencil function and operation processing of the stencil
	value.
	
	When a stencil value is written to the stencil buffer, its upper bits
	are overridden with the upper bits of the current stencil clear tag
	state so subsequent reads, prior to any subsequent stencil clear
	tag state change, properly return the updated lower bits.
	
	In this way, the stencil clear tag functionality provides a way to
	replace multiple bandwidth-intensive stencil clears with very
	inexpensive update of the stencil clear tag state.
	
	If used as expected with the client specifying 3 bits for the stencil
	tag, every 7 of 8 stencil-only clears of the entire stencil buffer can
	be substituted for an update of the current stencil clear tag rather
	than an actual update of all the framebuffer's stencil values.  Still,
	every 8th clear must be an actual stencil clear.  The net effect is
	that the aggregate cost of stencil clears is reduced by a factor of
	1/(2^n) where n is the number of bits devoted to the stencil tag.
	
	The application specifies two new pieces of state: 1) the number of
	upper stencil bits, n,  assigned to maintain the tag bits for each
	stencil value within the stencil buffer, and 2) a stencil clear tag
	value that packs the current tag and a reset value into a single
	integer values.  The upper n bits of the stencil clear tag value
	specify the current tag while the lower s-min(n,s) bits specify
	the current reset value, where s is the number of bitplanes in the
	stencil buffer and n is the current number of stencil tag bits.
	
	If zero stencil clear tag bits are assigned to the stencil tag
	encoding, then the stencil buffer operates in the conventional
	manner.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/stencil_clear_tag.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.stencil_clear_tag import *
from OpenGL.raw.GL.EXT.stencil_clear_tag import _EXTENSION_NAME

def glInitStencilClearTagEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_gather

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_gather to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a new set of texture functions
	(textureGather) to the shading language that determine 2x2 footprint
	that are used for linear filtering in a texture lookup, and return a
	vector consisting of the first component from each of the four
	texels in the footprint.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_gather.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_gather import *
from OpenGL.raw.GL.ARB.texture_gather import _EXTENSION_NAME

def glInitTextureGatherARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION